Delocalization of eigenvectors of random matrices with independent entries
Author: Mark Rudelson
Description: Duke Mathematical Journal
Keywords: 15B52; 60B20; delocalization of eigenvectors; random matrices; rotation-invariant ensembles
Date: 2015-10-01

Email
Password Forgot your password?
Show
Remember Email on this computer
Remember Password
Please wait...
No Project Euclid account? Create an account
or Sign in with your institutional credentials

We can help you reset your password using the email address linked to your Project Euclid account.

Email
Registered users receive a variety of benefits including the ability to customize email alerts, create favorite journals list, and save searches. Please note that a Project Euclid web account does not automatically grant access to full-text content. An institutional or society member subscription is required to view non-Open Access content. Contact customer_support@projecteuclid.org with any questions.
View Project Euclid Privacy Policy
All Fields are Required
* First Name
* Last/Family Name
* Email
* Password
Password Requirements: Minimum 8 characters, must include as least one uppercase, one lowercase letter, and one number or permitted symbol Valid Symbols for password:
~ Tilde
! Exclamation Mark
@ At sign
$ Dollar sign
^ Caret
( Opening Parenthesis
) Closing Parenthesis
_ Underscore
. Period
* Confirm Password
Please wait...
Web Account created successfully
1 October 2015 Delocalization of eigenvectors of random matrices with independent entries
Mark Rudelson, Roman Vershynin
Duke Math. J. 164(13): 2507-2538 (1 October 2015). DOI: 10.1215/00127094-3129809
PERSONAL SIGN IN
Full access may be available with your subscription
Email
Password Forgot your password?
Show
Remember Email on this computer
Remember Password
No Project Euclid account? Create an account
or Sign in with your institutional credentials
PURCHASE SINGLE ARTICLE
This article is only available to subscribers. It is not available for individual sale.
This will count as one of your downloads.
You will have access to both the presentation and article (if available).
This content is available for download via your institution's subscription. To access this item, please sign in to your personal account.
Email
Password Forgot your password?
Show
Remember Email on this computer
Remember Password
No Project Euclid account? Create an account
My Library
You currently do not have any folders to save your paper to! Create a new folder below.

## Abstract

We prove that an n×n random matrix G with independent entries is completely delocalized. Suppose that the entries of G have zero means, variances uniformly bounded below, and a uniform tail decay of exponential type. Then with high probability all unit eigenvectors of G have all coordinates of magnitude O(n−1/2), modulo logarithmic corrections. This comes as a consequence of a new, geometric approach to delocalization for random matrices.

## Citation

Download Citation

Mark Rudelson. Roman Vershynin. "Delocalization of eigenvectors of random matrices with independent entries." Duke Math. J. 164 (13) 2507 - 2538, 1 October 2015. https://doi.org/10.1215/00127094-3129809

## Information

Received: 21 August 2013; Revised: 10 October 2014; Published: 1 October 2015
First available in Project Euclid: 5 October 2015

zbMATH: 1352.60007
MathSciNet: MR3405592
Digital Object Identifier: 10.1215/00127094-3129809

Subjects:
Primary: 60B20
Secondary: 15B52

Keywords: delocalization of eigenvectors , random matrices , rotation-invariant ensembles

Rights: Copyright © 2015 Duke University Press
ACCESS THE FULL ARTICLE
PERSONAL SIGN IN
Full access may be available with your subscription
Email
Password Forgot your password?
Show
Remember Email on this computer
Remember Password
No Project Euclid account? Create an account
or Sign in with your institutional credentials
PURCHASE THIS CONTENT
PURCHASE SINGLE ARTICLE
This article is only available to subscribers.
It is not available for individual sale.
JOURNAL ARTICLE
32 PAGES

DOWNLOAD PDF + SAVE TO MY LIBRARY

GET CITATION
My Library
You currently do not have any folders to save your paper to! Create a new folder below.
Folder Name
Folder Description
< Previous Article
|
Next Article >
Duke Math. J.
Vol.164 • No. 13 • 1 October 2015
Duke University Press
Subscribe to Project Euclid
Receive erratum alerts for this article
Mark Rudelson, Roman Vershynin "Delocalization of eigenvectors of random matrices with independent entries," Duke Mathematical Journal, Duke Math. J. 164(13), 2507-2538, (1 October 2015)
Include:
Citation Only
Citation & Abstract
Format:
RIS
EndNote
BibTex
Print Friendly Version (PDF)

## KEYWORDS/PHRASES

Keywords
in
Remove
in
Remove
in
Remove
+ Add another field

## PUBLICATION TITLE:

All Titles
Choose Title(s)

## PUBLICATION YEARS

Range
Single Year

Clear Form